@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 
-__author__ = "Arturo Filastò"
-__version__ = "1.0.0"
+__author__ = "Open Observatory of Network Interference"
+__version__ = "1.0.1"
 
 __all__ = ['config', 'inputunit', 'kit',
            'lib', 'nettest', 'oonicli', 'reporter',
