@@ -139,6 +139,9 @@ class UnableToStartTor(DirectorException):
 class InvalidOONIBCollectorAddress(Exception):
     pass
 
+class InvalidOONIBBouncerAddress(Exception):
+    pass
+
 class AllReportersFailed(Exception):
     pass
 
@@ -153,6 +156,10 @@ class ReportAlreadyClosed(Exception):
 
 class TorStateNotFound(Exception):
     pass
+
+class TorControlPortNotFound(Exception):
+    pass
+
 class ReportNotCreated(Exception):
     pass
 
