@@ -38,44 +38,6 @@ def get_test_methods(item, method_prefix="test_"):
         pass
     return test_cases
 
-def loadNetTestString(net_test_string):
-    """
-    Load NetTest from a string.
-    WARNING input to this function *MUST* be sanitized and *NEVER* be
-    untrusted.
-    Failure to do so will result in code exec.
-
-    net_test_string:
-
-        a string that contains the net test to be run.
-    """
-    net_test_file_object = StringIO(net_test_string)
-
-    ns = {}
-    test_cases = []
-    exec net_test_file_object.read() in ns
-    for item in ns.itervalues():
-        test_cases.extend(get_test_methods(item))
-
-    if not test_cases:
-        raise e.NoTestCasesFound
-
-    return test_cases
-
-def loadNetTestFile(net_test_file):
-    """
-    Load NetTest from a file.
-    """
-    test_cases = []
-    module = filenameToModule(net_test_file)
-    for __, item in getmembers(module):
-        test_cases.extend(get_test_methods(item))
-
-    if not test_cases:
-        raise e.NoTestCasesFound
-
-    return test_cases
-
 def getTestClassFromFile(net_test_file):
     """
     Will return the first class that is an instance of NetTestCase.
@@ -173,20 +135,18 @@ def getNetTestInformation(net_test_file):
 class NetTestLoader(object):
     method_prefix = 'test'
     collector = None
+    requiresTor = False
 
     def __init__(self, options, test_file=None, test_string=None):
         self.onionInputRegex =  re.compile("(httpo://[a-z0-9]{16}\.onion)/input/([a-z0-9]{64})$")
         self.options = options
-        self.testCases, test_cases = None, None
+        self.testCases = []
 
         if test_file:
-            test_cases = loadNetTestFile(test_file)
+            self.loadNetTestFile(test_file)
         elif test_string:
-            test_cases = loadNetTestString(test_string)
+            self.loadNetTestString(test_string)
 
-        if test_cases:
-            self.setupTestCases(test_cases)
-   
     @property
     def requiredTestHelpers(self):
         required_test_helpers = []
@@ -245,7 +205,7 @@ class NetTestLoader(object):
                 'ip': '127.0.0.1'
         }
 
-        if config.probe_ip.address and (config.privacy.includeip or \
+        if config.probe_ip and config.probe_ip.address and (config.privacy.includeip or \
                 config.privacy.includeasn or \
                 config.privacy.includecountry or \
                 config.privacy.includecity):
@@ -388,6 +348,9 @@ class NetTestLoader(object):
         self.testVersion = test_class.version
         self.testName = test_class_name_to_name(test_class.name)
         self.testCases = test_cases
+        self.testClasses = set([])
+        for test_class, test_method in self.testCases:
+            self.testClasses.add(test_class)
 
     def checkOptions(self):
         """
@@ -397,7 +360,7 @@ class NetTestLoader(object):
         for test_class, test_method in self.testCases:
             test_classes.add(test_class)
 
-        for klass in test_classes:
+        for klass in self.testClasses:
             options = self.usageOptions()
             options.parseOptions(self.options)
 
@@ -407,6 +370,8 @@ class NetTestLoader(object):
             test_instance = klass()
             if test_instance.requiresRoot:
                 checkForRoot()
+            if test_instance.requiresTor:
+                self.requiresTor = True
             test_instance._checkRequiredOptions()
             test_instance._checkValidOptions()
 
@@ -488,13 +453,28 @@ class NetTest(object):
         """
         self.report = report
         self.testCases = net_test_loader.testCases
+        self.testClasses = net_test_loader.testClasses
+        self.testDetails = net_test_loader.testDetails
+
+        self.summary = {}
 
         # This will fire when all the measurements have been completed and
         # all the reports are done. Done means that they have either completed
         # successfully or all the possible retries have been reached.
         self.done = defer.Deferred()
+        self.done.addCallback(self.doneNetTest)
 
         self.state = NetTestState(self.done)
+    
+    def __str__(self):
+        return ' '.join(tc.name for tc, _ in self.testCases)
+    
+    def doneNetTest(self, result):
+        print "Summary for %s" % self.testDetails['test_name']
+        print "------------" + "-"*len(self.testDetails['test_name'])
+        for test_class in self.testClasses:
+            test_instance = test_class()
+            test_instance.displaySummary(self.summary)
 
     def doneReport(self, report_results):
         """
@@ -556,6 +536,7 @@ class NetTest(object):
             for input in test_class.inputs:
                 measurements = []
                 test_instance = test_class()
+                test_instance.summary = self.summary
                 for method in test_methods:
                     log.debug("Running %s %s" % (test_class, method))
                     measurement = self.makeMeasurement(test_instance, method, input)
@@ -642,7 +623,6 @@ class NetTestCase(object):
     inputFilename = None
 
     report = {}
-    report['errors'] = []
 
     usageOptions = usage.Options
 
@@ -653,13 +633,15 @@ class NetTestCase(object):
     requiredTestHelpers = {}
     requiredOptions = []
     requiresRoot = False
+    requiresTor = False
 
     localOptions = {}
     def _setUp(self):
         """
         This is the internal setup method to be overwritten by templates.
         """
-        pass
+        self.report = {}
+        self.inputs = None
 
     def setUp(self):
         """
@@ -674,9 +656,18 @@ class NetTestCase(object):
         postProcessing works exactly like test methods, in the sense that
         anything that gets written to the object self.report[] will be added to
         the final test report.
+        You should also place in this method any logic that is required for
+        generating the summary.
         """
         raise e.NoPostProcessor
 
+    def displaySummary(self, summary):
+        """
+        This gets called after the test has run to allow printing out of a
+        summary of the test run.
+        """
+        pass
+
     def inputProcessor(self, filename):
         """
         You may replace this with your own custom input processor. It takes as
@@ -704,7 +695,14 @@ class NetTestCase(object):
         log.debug("Running default input processor")
         with open(filename) as f:
             for line in f:
-                yield line.strip()
+                l = line.strip()
+                # Skip empty lines
+                if not l:
+                    continue
+                # Skip comment lines
+                elif l.startswith('#'):
+                    continue
+                yield l
 
     @property
     def inputFileSpecified(self):
@@ -742,13 +740,13 @@ class NetTestCase(object):
             a generator that will yield one item from the file based on the
             inputProcessor.
         """
-        if self.inputs:
-            return self.inputs
-
         if self.inputFileSpecified:
             self.inputFilename = self.localOptions[self.inputFile[0]]
             return self.inputProcessor(self.inputFilename)
 
+        if self.inputs:
+            return self.inputs
+ 
         return None
 
     def _checkValidOptions(self):
@@ -758,11 +756,14 @@ class NetTestCase(object):
                     raise e.InvalidOption
 
     def _checkRequiredOptions(self):
+        missing_options = []
         for required_option in self.requiredOptions:
             log.debug("Checking if %s is present" % required_option)
             if required_option not in self.localOptions or \
                 self.localOptions[required_option] == None:
-                raise e.MissingRequiredOption(required_option)
+                    missing_options.append(required_option)
+        if missing_options:
+            raise e.MissingRequiredOption(missing_options)
 
     def __repr__(self):
         return "<%s inputs=%s>" % (self.__class__, self.inputs)
