@@ -30,12 +30,14 @@ class HTTPRequestsTest(httpt.HTTPTest):
     name = "HTTP Requests Test"
     description = "Performs a HTTP GET request over Tor and one over the local network and compares the two results."
     author = "Arturo Filastò"
-    version = "0.2.3"
+    version = "0.2.4"
 
     usageOptions = UsageOptions
 
     inputFile = ['file', 'f', None,
             'List of URLS to perform GET and POST requests to']
+    requiresRoot = False
+    requiresTor = False
 
     # These values are used for determining censorship based on response body
     # lengths
@@ -56,6 +58,12 @@ class HTTPRequestsTest(httpt.HTTPTest):
         self.factor = self.localOptions['factor']
         self.report['control_failure'] = None
         self.report['experiment_failure'] = None
+        self.report['body_length_match'] =  None
+        self.report['body_proportion'] = None
+        self.report['factor'] = float(self.factor)
+        self.report['headers_diff'] = None
+        self.report['headers_match'] = None
+
         self.headers = {'User-Agent': [random.choice(userAgents)]}
 
     def compare_body_lengths(self, body_length_a, body_length_b):
@@ -71,7 +79,6 @@ class HTTPRequestsTest(httpt.HTTPTest):
             rel = 1/rel
 
         self.report['body_proportion'] = rel
-        self.report['factor'] = float(self.factor)
         if rel > float(self.factor):
             log.msg("The two body lengths appear to match")
             log.msg("censorship is probably not happening")
