@@ -92,16 +92,7 @@ def parseOptions():
 
     return dict(cmd_line_options)
 
-def shutdown(result):
-    """
-    This will get called once all the operations that need to be done in the
-    current oonicli session have been completed.
-    """
-    log.debug("Halting reactor")
-    try: reactor.stop()
-    except: pass
-
-def runWithDirector():
+def runWithDirector(logging=True, start_tor=True):
     """
     Instance the director, parse command line options and start an ooniprobe
     test!
@@ -110,8 +101,11 @@ def runWithDirector():
     config.global_options = global_options
     config.set_paths()
     config.read_config_file()
+    if not start_tor:
+        config.advanced.start_tor = False
     
-    log.start(global_options['logfile'])
+    if logging:
+        log.start(global_options['logfile'])
     
     if config.privacy.includepcap:
         try:
@@ -139,8 +133,6 @@ def runWithDirector():
 
         sys.exit(0)
 
-    d = director.start()
-
     #XXX: This should mean no bouncer either!
     if global_options['no-collector']:
         log.msg("Not reporting using a collector")
@@ -149,6 +141,11 @@ def runWithDirector():
 
     deck = Deck()
     deck.bouncer = global_options['bouncer']
+    start_tor = deck.requiresTor
+    if global_options['bouncer']:
+        start_tor = True
+    if global_options['collector']:
+        start_tor = True
 
     try:
         if global_options['testdeck']:
@@ -171,8 +168,10 @@ def runWithDirector():
         print net_test_loader.usageOptions().getUsage()
         sys.exit(2)
     
+    d = director.start(start_tor=start_tor)
+   
     def setup_nettest(_):
-        try: 
+        try:
             return deck.setup()
         except errors.UnableToLoadDeckInput as error:
             return defer.failure.Failure(error)
@@ -233,6 +232,8 @@ def runWithDirector():
             if not global_options['no-collector']:
                 if global_options['collector']:
                     collector = global_options['collector']
+                elif config.reports['collector']:
+                    collector = config.report['collector']
                 elif net_test_loader.collector:
                     collector = net_test_loader.collector
 
@@ -241,7 +242,8 @@ def runWithDirector():
                 raise errors.TorNotRunning
 
             test_details = net_test_loader.testDetails
-            yaml_reporter = YAMLReporter(test_details)
+            yaml_reporter = YAMLReporter(test_details,
+                                         report_filename=global_options['reportfile'])
             reporters = [yaml_reporter]
 
             if collector:
@@ -252,15 +254,13 @@ def runWithDirector():
                 except errors.InvalidOONIBCollectorAddress, e:
                     raise e
 
-            log.debug("adding callback for startNetTest")
-            director.startNetTest(net_test_loader, reporters)
-
-        director.allTestsDone.addBoth(shutdown)
+            netTestDone = director.startNetTest(net_test_loader, reporters)
+        return director.allTestsDone
 
     def start():
         d.addCallback(setup_nettest)
         d.addCallback(post_director_start)
         d.addErrback(director_startup_failed)
+        return d
 
-    reactor.callWhenRunning(start)
-    reactor.run()
+    return start()
