@@ -26,7 +26,8 @@ try:
     from scapy.packet import Packet
 except ImportError:
     log.err("Scapy is not installed.")
-
+    class Packet(object):
+        pass
 
 from ooni import errors
 
@@ -50,7 +51,7 @@ def createPacketReport(packet_list):
     report = []
     for packet in packet_list:
         report.append({'raw_packet': str(packet),
-            'summary': str(packet.summary())})
+            'summary': str([packet])})
     return report
 
 class OSafeRepresenter(SafeRepresenter):
@@ -165,15 +166,16 @@ class YAMLReporter(OReporter):
         the destination directory of the report
 
     """
-    def __init__(self, test_details, report_destination='.'):
+    def __init__(self, test_details, report_destination='.', report_filename=None):
         self.reportDestination = report_destination
 
         if not os.path.isdir(report_destination):
             raise InvalidDestination
-
-        report_filename = "report-" + \
-                test_details['test_name'] + "-" + \
-                otime.timestamp() + ".yamloo"
+        
+        if not report_filename:
+            report_filename = "report-" + \
+                              test_details['test_name'] + "-" + \
+                              otime.timestamp() + ".yamloo"
 
         report_path = os.path.join(self.reportDestination, report_filename)
 
@@ -367,7 +369,7 @@ class OONIBReporter(OReporter):
             log.err("Failed to parse collector response %s" % backend_response)
             log.exception(e)
             raise errors.OONIBReportCreationError
-        
+       
         if response.code == 406:
             # XXX make this more strict
             log.err("The specified input or nettests cannot be submitted to this collector.")
